// Copyright (C) 2010 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

// Build a LHS design with 2 variables

// References
//
// "A User's Guide to LHS: Sandia's Latin Hypercube Sampling Software"
// Gregory D. Wyss and Kelly H. Jorgensen
// 1998
//
// "A Comparison of Three Methods for Selecting Values of Input Variables in the Analysis of
// Output from a Computer Code"
// M. D. McKay, R. J. Beckman, W. J. Conover
// Technometrics, Vol. 21, No. 2 (May, 1979), pp. 239-245

mprintf("Plot 5 points in a 2D LHS sampling\n");
n = 5;
s =  2;
sampling = nisp_buildlhs ( s , n );
scf();
plot ( sampling(:,1) , sampling(:,2) , "bo" );
// Add the cuts
cut = linspace ( 0 , 1 , n + 1 );
for i = 1 : n + 1
  plot( [cut(i) cut(i)] , [0 1] , "-" )
end
for i = 1 : n + 1
  plot( [0 1] , [cut(i) cut(i)] , "-" )
end
xtitle("Latin Hypercube Sampling: 5 points","X1","X2");

mprintf("Plot 1000 points in a 2D LHS sampling\n");
n = 100;
s =  2;
sampling = nisp_buildlhs ( s , n );
scf();
drawlater();
plot ( sampling(:,1) , sampling(:,2) , "bo" );
xtitle("Latin Hypercube Sampling: 1 000 points","X1","X2");
drawnow();

scf();
mprintf("Plot histogram of the projection of\n");
mprintf("1000 points in 2D of LHS sampling\n");
subplot(2,1,1);
c = linspace(0,1,n+1);
histplot ( c , sampling(:,1));
xtitle("Latin Hypercube Sampling: 100 points","X1","P(X1)");
subplot(2,1,2);
histplot ( c , sampling(:,2));
xtitle("Latin Hypercube Sampling: 100 points","X2","P(X2)");
//
// Load this script into the editor
//
filename = 'demo_build_LHS.sce';
dname = get_absolute_file_path(filename);
editor ( dname + filename );

