// Copyright (C) 2009 - CEA - Jean-Marc Martinez
// Copyright (C) 2009-2011 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

//
// Draw the scatter plots of the product function.
// Two normal random variables.
//

//
// normpdf --
//   Computes the Normal probability distribution function
// Arguments
//   x : the outcome
//   mu : the mean (default 0)
//   sigma : the standard deviation (default 1)
//   p : the probability
// Calling sequences
//   p = normpdf ( x )
//   p = normpdf ( x , mu , sigma )
//
function p = normpdf ( varargin )
  [lhs,rhs]=argn();
  if ( ( rhs <> 1 ) & ( rhs <> 3 ) ) then
    errmsg = msprintf(gettext("%s: Unexpected number of input arguments : %d provided while %d or %d are expected."), "normpdf" , rhs , 1 , 3 );
    error(errmsg)
  end
  select rhs
  case 1 then
    x = varargin ( 1 )
    mu = 0.0
    sigma = 1.0
  case 3 then
    x = varargin ( 1 )
    mu = varargin ( 2 )
    sigma = varargin ( 3 )
  end
  y = ( x - mu ) ./ sigma;
  p = exp ( - 0.5 .* y .* y )  ./ ( sigma .* sqrt ( 2.0 * %pi ) );
endfunction


//
// Another case.
// mu2=0 implies S1=0.
// But Y is not independent of X1.
// First variable
// Normal
mu1 = 0.1;
sigma1 = 0.5;
// Second variable
// Normal
mu2 = 0;
sigma2 = 2.5;
exact = nisp_productsa ( [mu1,mu2]' , [sigma1,sigma2]' )
//
np = 10000;

// Define a sampling for x1.
u = grand(np,1,"def");
x1 = cdfnor("X",mu1*ones(np,1),sigma1*ones(np,1),u,1-u);
// Define a sampling for x2.
u = grand(np,1,"def");
x2 = cdfnor("X",mu2*ones(np,1),sigma2*ones(np,1),u,1-u);
// Merge the two samplings
x = [x1 x2];
// Perform the experiments
y = nisp_product (x);
// Scatter plots : y depending on X_i
scf();
for k=1:2
  subplot(2,1,k);
  plot(x(:,k),y,'rx');
  xistr="X"+string(k);
  xtitle("Case mu2=0 - Scatter plot for "+xistr,xistr,"Y");
end

// Histogram of Y
scf();
histplot(50,y);
xtitle("Histogram of Y","Y","P(Y)");
//
// The probability distribution function of a product of 
// two normal variables with zero mean is a 
// modified Bessel function of the second kind.
// Here, the means are nonzero... but the 
// function fits quite accurately enough anyway.
x = linspace(-10,10,1000);
alpha = 0;
p =  besselk(alpha,abs(x)/(sigma1*sigma2))/(%pi*sigma1*sigma2);
plot(x,p,"r-");
legend(["Experiment","Bessel 2nd kind"]);

//
// Load this script into the editor
//
filename = 'product_scatter2.sce';
dname = get_absolute_file_path(filename);
editor ( dname + filename );

