
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
// Copyright (C) 2010 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html


//
// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

// Compute the first order sensitivity indices of the ishigami function.
// Three random variables uniform in [-pi,pi].
function y=ishigami(x)
    a=7.
    b=0.1
    s1=sin(x(:,1))
    s2=sin(x(:,2))
    x34 = x(:,3).^4
    y(:,1) = s1 + a.*s2.^2 + b.*x34.*s1
endfunction
function x = myrandgen ( nx, n, step, i)
    if ( step == 1 ) then
        x = grand(n,nx,"unf",-%pi,%pi)
    else
        sn = sqrt(n)
        xi = grand(sn,1,"unf",-%pi,%pi)
        xr = grand(n,nx-1,"unf",-%pi,%pi)
        x = [xr(:,1:i-1),xi.*.ones(sn,1),xr(:,i:nx-1)]
    end
endfunction
grand("setsd",0);
a=7.;
b=0.1;
exact = nisp_ishigamisa(a,b);
n = 500;
nx = 3;
// See the sampling in step 1
step = 1;
x = myrandgen ( nx, 4, step, []);
assert_checkequal ( size(x) , [4,nx] );
// See the sampling in step 2.
// See how the variable #3 is replicated.
step = 2;
x = myrandgen ( nx, 16, step, 3);
assert_checkequal ( size(x) , [16,nx] );
assert_checkequal ( length(unique(x(:,3))) , 4 );
[ s , nbevalf ] = nisp_bruteforcesa ( ishigami , nx , myrandgen , n );
mprintf("S1 : %f (expected = %f)\n", s(1), exact.S1);
mprintf("S2 : %f (expected = %f)\n", s(2), exact.S2);
mprintf("S3 : %f (expected = %f)\n", s(3), exact.S3);
assert_checkalmostequal ( s(1), exact.S1 , 1.e-1 );
assert_checkalmostequal ( s(2), exact.S2 , 1.e-1 );
assert_checkalmostequal ( s(3), exact.S3 , [] , 1.e-1 );
assert_checkequal ( nbevalf , 750500 );

