
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
// Copyright (C) 2010 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html


//
// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

// Compute the first order sensitivity indices of the ishigami function.
// Three random variables uniform in [-pi,pi].
function y = ishigami (x)
    a=7.
    b=0.1
    s1=sin(x(:,1))
    s2=sin(x(:,2))
    x34 = x(:,3).^4
    y(:,1) = s1 + a.*s2.^2 + b.*x34.*s1
endfunction
function x = myrandgen ( m , i )
    x = grand(m,1,"unf",-%pi,%pi)
endfunction
grand("setsd",0);
a=7.;
b=0.1;
exact = nisp_ishigamisa ( a , b );
//
//
n = 100000;
nx = 3;
[ s , nbevalf ] = nisp_sobolsa ( ishigami , nx , myrandgen , n );
assert_checkalmostequal ( s(1), exact.S1 , 1.e-1 );
assert_checkalmostequal ( s(2), exact.S2 , 1.e-2 );
assert_checkalmostequal ( s(3), exact.S3 , [] , 1.e-2 );
assert_checkequal ( nbevalf , 400000 );
//
// With default n
grand("setsd",0);
[ s , nbevalf ] = nisp_sobolsa ( ishigami , nx , myrandgen );
assert_checkalmostequal ( s(1), exact.S1 , 1.e-1 );
assert_checkalmostequal ( s(2), exact.S2 , 1.e-2 );
assert_checkalmostequal ( s(3), exact.S3 , [] , 1.e-2 );
assert_checkequal ( nbevalf , 40000 );
//
// With default randgen
grand("setsd",0);
function y = ishigami3 ( x )
    // From [0,1] to [-pi,pi]
    x = 2*%pi.*x - %pi
    a=7.
    b=0.1
    s1=sin(x(:,1))
    s2=sin(x(:,2))
    x34 = x(:,3).^4
    y(:,1) = s1 + a.*s2.^2 + b.*x34.*s1
endfunction
[ s , nbevalf ] = nisp_sobolsa ( ishigami3 , nx );
assert_checkalmostequal ( s(1), exact.S1 , 1.e-1 );
assert_checkalmostequal ( s(2), exact.S2 , 1.e-2 );
assert_checkalmostequal ( s(3), exact.S3 , [] , 1.e-2 );
assert_checkequal ( nbevalf , 40000 );
//
// With additionnal arguments for f.
function y = ishigami2 ( x , a , b )
    s1=sin(x(:,1))
    s2=sin(x(:,2))
    x34 = x(:,3).^4
    y(:,1) = s1 + a.*s2.^2 + b.*x34.*s1
endfunction
a=7.;
b=0.1;
grand("setsd",0);
[ s , nbevalf ] = nisp_sobolsa ( list(ishigami2,a,b) , nx , myrandgen );
assert_checkalmostequal ( s(1), exact.S1 , 1.e-1 );
assert_checkalmostequal ( s(2), exact.S2 , 1.e-2 );
assert_checkalmostequal ( s(3), exact.S3 , [] , 1.e-2 );
assert_checkequal ( nbevalf , 40000 );
//
// With additionnal arguments for randgen.
function x = myrandgen2 ( n , i , xmin , xmax )
    x = grand(n,1,"unf",xmin,xmax)
endfunction
grand("setsd",0);
[ s , nbevalf ] = nisp_sobolsa ( ishigami , nx , list(myrandgen2,-%pi,%pi) );
assert_checkalmostequal ( s(1), exact.S1 , 1.e-1 );
assert_checkalmostequal ( s(2), exact.S2 , 1.e-2 );
assert_checkalmostequal ( s(3), exact.S3 , [] , 1.e-2 );
assert_checkequal ( nbevalf , 40000 );
//
// Get total sensitivity indices.
grand("setsd",0);
[ s , nbevalf , st ] = nisp_sobolsa ( ishigami , nx , myrandgen );
assert_checkalmostequal ( s(1), exact.S1 , 1.e-1 );
assert_checkalmostequal ( s(2), exact.S2 , 1.e-2 );
assert_checkalmostequal ( s(3), exact.S3 , [] , 1.e-2 );
assert_checkequal ( nbevalf , 70000 );
assert_checkalmostequal ( st(1), exact.ST1 , 1.e-2 );
assert_checkalmostequal ( st(2), exact.ST2 , 1.e-2 );
assert_checkalmostequal ( st(3), exact.ST3 , [] , 1.e-2 );
//
// Get all sensitivity indices.
grand("setsd",0);
[ s , nbevalf , st , mi , si ] = nisp_sobolsa ( ishigami , nx , myrandgen );
assert_checkalmostequal ( s(1), exact.S1 , 1.e-1 );
assert_checkalmostequal ( s(2), exact.S2 , 1.e-2 );
assert_checkalmostequal ( s(3), exact.S3 , [] , 1.e-2 );
assert_checkequal ( nbevalf , 100000 );
assert_checkalmostequal ( st(1), exact.ST1 , 1.e-2 );
assert_checkalmostequal ( st(2), exact.ST2 , 1.e-2 );
assert_checkalmostequal ( st(3), exact.ST3 , [] , 1.e-2 );
miexpected = [
1,0,0;
0,1,0;   
0,0,1;   
1,1,0;   
1,0,1;   
0,1,1;   
1,1,1
];
assert_checkequal ( mi , miexpected );
siexpected = [
exact.S1
exact.S2
exact.S3
exact.S12
exact.S13
exact.S23
exact.S123
];
assert_checkalmostequal ( si, siexpected , [] , 1.e-1 );
assert_checkalmostequal ( sum(si) , 1 , 10 * %eps );

